Py4JPythonClientPerThread (py4j-java 0.10.9.7 API)

Package py4j

## Interface Py4JPythonClientPerThread

- All Superinterfaces:
    `Py4JPythonClient`
  All Known Implementing Classes:
    `PythonClient`

      public interface Py4JPythonClientPerThread
      extends Py4JPythonClient

- - ### Method Summary

    All Methods Instance Methods Abstract Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `Gateway` | `getGateway()` |
    `Py4JJavaServer` | `getJavaServer()` |
    `ClientServerConnection` | `getPerThreadConnection()` |
    `void` | `setGateway​(Gateway gateway)` |
    `void` | `setJavaServer​(Py4JJavaServer javaServer)` |
    `void` | `setPerThreadConnection​(ClientServerConnection clientServerConnection)` |

    - ### Methods inherited from interface py4j.Py4JPythonClient

      `copyWith, getAddress, getPort, getPythonServerEntryPoint, getReadTimeout, isMemoryManagementEnabled, sendCommand, sendCommand, shutdown`

- - ### Method Detail

    - #### getPerThreadConnection

          ClientServerConnection getPerThreadConnection()

    - #### setPerThreadConnection

          void setPerThreadConnection​(ClientServerConnection clientServerConnection)

    - #### getGateway

          Gateway getGateway()

    - #### setGateway

          void setGateway​(Gateway gateway)

    - #### getJavaServer

          Py4JJavaServer getJavaServer()

    - #### setJavaServer

          void setJavaServer​(Py4JJavaServer javaServer)